#include "testlib.h"
#include <iostream>
#include <vector>
#include <cmath>
#include <algorithm>

using namespace std;

const long long MAX_DIFF = 10000000;
const long long MAX_SQRT = 1000000;
const long long MAX_N = 1000;
const long long MAX_A_B = 1000000000000LL;

vector<long long> generateSmallPrimes(long long limit) {
    vector<bool> isPrime(limit + 1, true);
    isPrime[0] = isPrime[1] = false;

    for (long long i = 2; i * i <= limit; ++i) {
        if (isPrime[i]) {
            for (long long j = i * i; j <= limit; j += i) {
                isPrime[j] = false;
            }
        }
    }

    vector<long long> primes;
    for (long long i = 2; i <= limit; ++i) {
        if (isPrime[i]) primes.push_back(i);
    }
    return primes;
}

long long generateSegmentedSieve(long long low, long long high, const vector<long long>& smallPrimes) {
    vector<bool> rangePrime(high - low + 1, true);

    for (long long prime : smallPrimes) {
        long long base = max(prime * prime, (low + prime - 1) / prime * prime);
        for (long long j = base; j <= high; j += prime) {
            rangePrime[j - low] = false;
        }
    }

    if (low == 1) rangePrime[0] = false;
    long long ret = 0;
    for (const auto it : rangePrime) {
        ret += it;
    }
    return ret;
}

int main(int argc, char* argv[]) {
    registerValidation(argc, argv);

    int n = inf.readInt(1, MAX_N, "n");
    inf.readEoln();

    vector<pair<long long, long long>> ranges(n);
    long long totalRangeSum = 0;

    const auto smallPrimes = generateSmallPrimes(MAX_SQRT);

    for (int i = 0; i < n; ++i) {
        long long a = inf.readLong(1, MAX_A_B, "a_i");
        inf.readSpace();
        long long b = inf.readLong(a, MAX_A_B, "b_i");
        inf.readEoln();

        ensuref(b - a + 1 <= MAX_DIFF, "Range size exceeds 1,000,000");
        totalRangeSum += (b - a + 1);
        ensuref(totalRangeSum <= MAX_DIFF, "Total range size exceeds 1,000,000");

        ranges[i] = {a, b};
        std::cout << generateSegmentedSieve(a, b, smallPrimes) << std::endl;
    }
    inf.readEof();

    return 0;
}
