#!/bin/bash

# Paths
TESTGEN_CPP="./author/testgen.cpp"   # Test generator source file
SOLUTION_CPP="./author/author.cpp"  # Solution source file
TESTLIB_H="./author/testlib.h"      # Testlib header file
TESTS_DIR="./tests"                 # Directory to store tests

# Executables
TESTGEN_EXEC="./author/testgen"     # Compiled test generator
SOLUTION_EXEC="./author/solution"   # Compiled solution

# Compilation commands
echo "Compiling test generator..."
g++ "$TESTGEN_CPP" -o "$TESTGEN_EXEC" -std=c++17 || {
    echo "Failed to compile $TESTGEN_CPP." >&2
    exit 1
}

echo "Compiling solution..."
g++ "$SOLUTION_CPP" -o "$SOLUTION_EXEC" -std=c++17 || {
    echo "Failed to compile $SOLUTION_CPP." >&2
    exit 1
}

# Ensure the tests directory exists
mkdir -p "$TESTS_DIR"

# Number of test case types and tests per type
TEST_CASE_TYPES=(1 2 3)
TESTS_PER_TYPE=15

# Generate tests for each type
for CASE_TYPE in "${TEST_CASE_TYPES[@]}"; do
    for ((i=1; i<=TESTS_PER_TYPE; i++)); do
        TEST_INDEX=$(( (CASE_TYPE - 1) * TESTS_PER_TYPE + i ))
        INPUT_FILE="${TESTS_DIR}/test_${TEST_INDEX}.in"
        OUTPUT_FILE="${TESTS_DIR}/test_${TEST_INDEX}.out"

        echo "Generating test $TEST_INDEX (case type $CASE_TYPE)..."

        # Generate input file
        $TESTGEN_EXEC $CASE_TYPE > "$INPUT_FILE" || {
            echo "Failed to generate input for test $TEST_INDEX." >&2
            exit 1
        }

        # Generate output file using the solver
        $SOLUTION_EXEC < "$INPUT_FILE" > "$OUTPUT_FILE" || {
            echo "Failed to generate output for test $TEST_INDEX." >&2
            exit 1
        }
    done
done

echo "Test generation completed. Inputs and outputs are in ${TESTS_DIR}/."
